#!/bin/sh -euf
# -*- mode: Shell-script; tab-width: 8; fill-column: 70; -*- 
# $Id: incoming_upload.sh,v 0.0.1 2005/12/13 20:20:11 legion Exp $ 

incoming_user="$USER"
incoming_serv="cvs.altlinux.org"
incoming_dir=

cnf="$HOME/.incoming/config"
[ ! -f "$cnf" ] || . "$cnf" 

PROG="${0##*/}"
files=
verbose=
TEST=

usage() {
    [ "$1" = 0 ] || exec >&2
    cat << EOF
Usage: $PROG [options] <DIR> [<DIR> ...]
Usage: $PROG [options] --files <SRPM> [<SRPM> ...]

Options:
    --test          Just go through the motions
	-f, --files     Consider arguments as file names
    -h, --help      Show this message
    -v, --verbose   Print a message for each action

EOF
    [ -n "$1" ] && exit "$1" || exit
}

msg() {
  [ -z "$verbose" ] || printf %s\\n "$*"
}

fatal() {
  printf %s\\n "$PROG: FATAL: $*" >&2
  exit 1
}

files() {
  { [ -z "$files" ] && 
	  find $@ -name '*src.rpm' || 
	  { printf %s\\n "$@" |grep '.src.rpm'; } 
  } |xargs -i readlink $verbose -e '{}' || fatal "Unable get files"
}

TEMP=`getopt -n $PROG -o h,v,t:,f -l help,verbose,test-only,files -- "$@"` || usage
eval set -- "$TEMP"
while :; do
    case $1 in
	-f| --files) files=1
		;;
	-h| --help) usage 0
	    ;;
	-v| --verbose) verbose=-v
	    ;;
	--test-only) TEST=echo; verbose=
		;;
	--) shift; break
	    ;;
	*) fatal "unrecognized option: $1"
	    ;;
    esac
    shift
done

[ "$#" -gt 0 ] || fatal "more arguments required"
lst="$(files $@)"
[ -n "$lst" ] || fatal "Nothing to do."

msg "Changing permissions ..."
printf %s\\n "$lst" |xargs $TEST chmod 644 -- || fatal "chmod FAILED"

msg "Checking ..."
$TEST sisyphus_check $verbose --files $lst  || fatal "sisyphus_check FAILED" 

msg "Transfering ..."
$TEST rsync $verbose -a $lst "${incoming_user:+$incoming_user@}$incoming_serv:$incoming_dir" || fatal "rsync FAILED"
